@@ -78,6 +78,19 @@ var prReviews = shortenQuery(`
 			reactionGroups{content,users{totalCount}}
 		}
 		pageInfo{hasNextPage,endCursor}
+		totalCount
+	}
+`)
+
+var prLatestReviews = shortenQuery(`
+	latestReviews(first: 100) {
+		nodes {
+			author{login},
+			authorAssociation,
+			submittedAt,
+			body,
+			state
+		}
 	}
 `)
 
@@ -179,6 +192,7 @@ var PullRequestFields = append(IssueFields,
 	"headRepositoryOwner",
 	"isCrossRepository",
 	"isDraft",
+	"latestReviews",
 	"maintainerCanModify",
 	"mergeable",
 	"mergeCommit",
@@ -228,6 +242,8 @@ func PullRequestGraphQL(fields []string) string {
 			q = append(q, prReviewRequests)
 		case "reviews":
 			q = append(q, prReviews)
+		case "latestReviews":
+			q = append(q, prLatestReviews)
 		case "files":
 			q = append(q, prFiles)
 		case "commits":
