@@ -116,6 +116,9 @@ func (r *ResolvedRemotes) BaseRepo(io *iostreams.IOStreams) (ghrepo.Interface, e
 
 	baseName := repoNames[0]
 	if len(repoNames) > 1 {
+		// hide the spinner in case a command started the progress indicator before base repo was fully
+		// resolved, e.g. in `gh issue view`
+		io.StopProgressIndicator()
 		err := prompt.SurveyAskOne(&survey.Select{
 			Message: "Which should be the base repository (used for e.g. querying issues) for this directory?",
 			Options: repoNames,
